@@ -2,12 +2,14 @@
  *  \file IMP/pmi.h
  *  \brief Include all non-deprecated headers in IMP.pmi.
  *
- *  Copyright 2007-2015 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2017 IMP Inventors. All rights reserved.
  */
 
 #ifndef IMP_PMI_H
 #define IMP_PMI_H
 #include <IMP/pmi/CompositeRestraint.h>
+#include <IMP/pmi/InternalCoordinatesConstraint.h>
+#include <IMP/pmi/MembraneRestraint.h>
 #include <IMP/pmi/Resolution.h>
 #include <IMP/pmi/SigmoidRestraintSphere.h>
 #include <IMP/pmi/Symmetric.h>
